
import { MouseEventHandler, ReactNode } from 'react';
import { motion, Variants } from 'framer-motion';
import { Card } from "../ui/card";

interface CardClickableDeveloperProps {
    index: number; // Índice do card para definir o atraso da animação
    initial?: 'hidden' | 'visible'; // Estado inicial da animação
    animate?: 'hidden' | 'visible'; // Estado de animação
    variants?: Variants; // Variants de animação
    transition?: { delay?: number; duration?: number }; // Transição de animação
    children?: ReactNode; // Conteúdo do card
    cardProps?: ReactNode; // Propriedades adicionais do card
    onClick?: MouseEventHandler<HTMLDivElement>;
}

export default function CardClickableDeveloper({
    index,
    initial = 'hidden',
    animate = 'visible',
    variants = {
        hidden: { opacity: 0, x: -500 },
        visible: { opacity: 1, x: 0 },
    },
    transition = { delay: index * 7, duration: 0.7 },
    children,
    onClick,
}: CardClickableDeveloperProps): JSX.Element {
    return (
        <motion.div
            initial={initial}
            animate={animate}
            variants={variants}
            transition={transition}
            onClick={onClick}
            className='cursor-pointer '
        >
            <Card className='w-fit shadow-none border-0'>
                <div className="flex flex-row px-[20px] py-[20px] rounded-full gap-[24px] max-lg:flex-col">
                    {children}
                </div>
            </Card>
        </motion.div>
    )
}
