import { ReactNode } from "react";
import { motion, Variants } from "framer-motion";
import { Card, CardHeader, CardTitle } from "../ui/card";
import React from "react";

interface CardContentDeveloperProps {
  index: number; // Índice do card para definir o atraso da animação
  initial?: "hidden" | "visible"; // Estado inicial da animação
  animate?: "hidden" | "visible"; // Estado de animação
  variants?: Variants; // Variants de animação
  transition?: { delay?: number; duration?: number }; // Transição de animação
  children?: ReactNode; // Conteúdo do card
  cardProps?: ReactNode; // Propriedades adicionais do card
  title?: string; // Texto do título do card
  backgroundColor?: string; // Cor de fundo do título
}

export default function CardContentDeveloper({
  index,
  initial = "hidden",
  animate = "visible",
  variants = {
    hidden: { opacity: 0, x: -500 },
    visible: { opacity: 1, x: 0 },
  },
  transition = { delay: index * 7, duration: 0.7 },
  title = "Default",
  children,
  backgroundColor = "#3d3dff",
}: CardContentDeveloperProps): JSX.Element {
  return (
    <motion.div
      initial={initial}
      animate={animate}
      variants={variants}
      transition={transition}
      className="w-full"
    >
      <Card className="w-full shadow-none border-0">
        <CardHeader className="flex flex-row justify-between">
          <CardTitle
            className={`flex justify-center bg-[${backgroundColor}] w-fit px-[12px] py-[4px] rounded-full text-[14px] text-[#fff] items-center  font-[500]`}
          >
            {title}
          </CardTitle>
        </CardHeader>
        <div className="flex flex-row px-[24px] rounded-full pb-[24px] gap-[24px] max-lg:flex-col">
          {React.Children.map(children, (child) => (
            <div className="flex-grow">{child}</div>
          ))}
        </div>
      </Card>
    </motion.div>
  );
}
