import { Label } from "../ui/label";
import { Input } from "../ui/input";
import { ReactNode } from "react";

interface InputDeveloperProps {
    label?: string;
    type?: string;
    id?: string;
    placeholder?: string;
    icon?: ReactNode; // Ícone opcional na frente do input
    iconBehind?: ReactNode; // Ícone opcional atrás do input
    errorMessage?: string; // Mensagem de erro opcional
}

export default function InputDeveloper({
    label = "Label",
    type = "text",
    id,
    placeholder,
    icon,
    iconBehind,
    errorMessage,
}: InputDeveloperProps): JSX.Element {
    return (
        <div className="grid w-full items-start text-left gap-1.5">
            <Label className="text-[#101828] font-[400]">{label}</Label>
            <div className="relative">
                {icon && (
                    <div className="absolute left-0 inset-y-0 flex items-center pl-3 pointer-events-none">
                        {icon}
                    </div>
                )}
                <Input
                    type={type}
                    id={id}
                    placeholder={placeholder}
                    className={`pl-${icon ? '40' : '16'} pr-${iconBehind ? '40' : '16'} border-2 border-[#eaecf0] rounded-[16px] w-full focus:border-[#3d3dff] focus:outline-none transition-all duration-200 ease-in-out h-[48px] text-[#101828] font-[400] bg-[#f2f4f7] shadow-none`}
                />
                {iconBehind && (
                    <div className="absolute right-0 inset-y-0 flex items-center pr-3 pointer-events-none">
                        {iconBehind}
                    </div>
                )}
            </div>
            {errorMessage && (
                <p className="text-red-500 text-xs mt-1">{errorMessage}</p>
            )}
        </div>
    );
}